# =====================================
# generator=datazen
# version=3.2.3
# hash=1ced247e5dcefc85302a056ef8fe63cd
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A tool for working with scalable vector graphics."
PKG_NAME = "svgen"
VERSION = "0.9.0"
